MatchMaker
=================================

.. currentmodule:: alfred3_interact.match

.. autoclass:: MatchMaker
   :show-inheritance:




   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
      :toctree:




      ~MatchMaker.check_activation


      ~MatchMaker.check_quota


      ~MatchMaker.match


      ~MatchMaker.match_chain


      ~MatchMaker.match_random


      ~MatchMaker.match_to


      ~MatchMaker.toggle_activation







   .. rubric:: Attributes

   .. autosummary::
      :template: autosummary/attribute.rst
      :toctree:


         ~MatchMaker.active
         ~MatchMaker.waiting_members
